# Sanic Macrobase Driver | Build fast. Run fast. With him.

Driver with [Sanic server](https://github.com/huge-success/sanic) implementation from [Macrobase framework](https://github.com/mbcores/macrobase).